@@ -1,6 +1,6 @@
 package ZMQ::FFI::ErrorHandler;
 {
-  $ZMQ::FFI::ErrorHandler::VERSION = '0.06';
+  $ZMQ::FFI::ErrorHandler::VERSION = '0.07';
 }
 
 use Moo;
@@ -71,11 +71,11 @@ ZMQ::FFI::ErrorHandler
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 AUTHOR
 
-Dylan Cali <calid1984@gmail.com
+Dylan Cali <calid1984@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
