@@ -1,6 +1,6 @@
 package ZMQ::FFI::SoWrapper;
 {
-  $ZMQ::FFI::SoWrapper::VERSION = '0.06';
+  $ZMQ::FFI::SoWrapper::VERSION = '0.07';
 }
 
 use Moo::Role;
@@ -47,11 +47,11 @@ ZMQ::FFI::SoWrapper
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 AUTHOR
 
-Dylan Cali <calid1984@gmail.com
+Dylan Cali <calid1984@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
