@@ -1,6 +1,6 @@
 package ZMQ::FFI::SocketBase;
 {
-  $ZMQ::FFI::SocketBase::VERSION = '0.06';
+  $ZMQ::FFI::SocketBase::VERSION = '0.07';
 }
 
 use Moo;
@@ -14,6 +14,10 @@ use FFI::Raw;
 use ZMQ::FFI::Constants qw(:all);
 
 use Try::Tiny;
+use Math::Int64 qw(
+    int64_to_native  native_to_int64
+    uint64_to_native native_to_uint64
+);
 
 has ffi => (
     is => 'ro',
@@ -154,12 +158,10 @@ sub has_pollout {
 sub get {
     my ($self, $opt, $opt_type) = @_;
 
-    my $pack_type = $self->_get_pack_type($opt_type);
+    my $optval = $self->_pack($opt_type, 0);
 
-    my $optval     = pack $pack_type, 0;
     my $optval_len = pack 'L!', length($optval);
-
-    my $sizeof_ptr     = length(pack('L!'));
+    my $sizeof_ptr = length(pack('L!'));
 
     my $optval_ptr =
         $opt_type eq 'binary' ?
@@ -179,19 +181,7 @@ sub get {
         )
     );
 
-    if ($opt_type eq 'binary') {
-        $optval_len = unpack 'L!', $optval_len;
-
-        if ($optval_len == 0) {
-            return;
-        }
-
-        $optval = $optval_ptr->tostr($optval_len);
-    }
-    else {
-        $optval = unpack $pack_type, $optval;
-    }
-
+    $optval = $self->_unpack($opt_type, $optval, $optval_ptr, $optval_len);
     return $optval;
 }
 
@@ -212,11 +202,10 @@ sub set {
         );
     }
     else {
-        my $pack_type = $self->_get_pack_type($opt_type);
-        my $packed    = pack $pack_type, $opt_val;
+        my $packed = $self->_pack($opt_type, $opt_val);
 
         my $opt_ptr   = unpack('L!', pack('P', $packed));
-        my $opt_len   = length(pack($pack_type, 0));
+        my $opt_len   = length($packed);
 
         $self->check_error(
             'zmq_setsockopt',
@@ -230,13 +219,53 @@ sub set {
     }
 }
 
-sub _get_pack_type {
+sub _pack {
+    my ($self, $opt_type, $val) = @_;
+
+    my $packed;
+    for ($opt_type) {
+        when (/^int64_t$/)  { $packed = int64_to_native($val)  }
+        when (/^uint64_t$/) { $packed = uint64_to_native($val) }
+
+        default {
+            $packed = pack $self->_pack_type($opt_type), $val;
+        }
+    }
+
+    return $packed;
+}
+
+sub _unpack {
+    my ($self, $opt_type, $optval, $optval_ptr, $optval_len) = @_;
+
+    for ($opt_type) {
+        when (/^binary$/) {
+            $optval_len = unpack 'L!', $optval_len;
+
+            if ($optval_len == 0) {
+                return;
+            }
+
+            $optval = $optval_ptr->tostr($optval_len);
+        }
+
+        when (/^int64_t$/)  { $optval = native_to_int64($optval)   }
+        when (/^uint64_t$/) { $optval = native_to_uint64($optval)  }
+
+        default {
+            $optval = unpack $self->_pack_type($opt_type), $optval;
+        }
+    }
+
+    return $optval;
+}
+
+sub _pack_type {
     my ($self, $zmqtype) = @_;
 
-    given ($zmqtype) {
+    # these are the only opts we use native perl packing for
+    for ($zmqtype) {
         when (/^int$/)      { return 'i!' }
-        when (/^int64_t$/)  { return 'l!' }
-        when (/^uint64_t$/) { return 'L!' }
         when (/^binary$/)   { return 'L!' }
 
         default { croak "unsupported type '$self->ffi->{zmqtype}'" }
@@ -368,11 +397,11 @@ ZMQ::FFI::SocketBase
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 AUTHOR
 
-Dylan Cali <calid1984@gmail.com
+Dylan Cali <calid1984@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
