@@ -1,6 +1,6 @@
 package ZMQ::FFI::Versioner;
 {
-  $ZMQ::FFI::Versioner::VERSION = '0.06';
+  $ZMQ::FFI::Versioner::VERSION = '0.07';
 }
 
 use Moo;
@@ -34,11 +34,11 @@ ZMQ::FFI::Versioner
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 AUTHOR
 
-Dylan Cali <calid1984@gmail.com
+Dylan Cali <calid1984@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
